import greenfoot.*;

/**
 * An Actor which is meant to be added to a
 * Layer.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class LayerActor extends Actor
{
    private Layer layer;
    
    /** Used by the system: don't touch! */
    int oldX, oldY;
    
    /**
     * Create a new LayerActor.
     */
    public LayerActor()
    {
        this.layer = null;
    }
    
    /**
     * Returns the layer the layer actor is in.
     */
    public Layer getLayer()
    {
        testLayer();
        return layer;
    }
    
    /**
     * Sets the location of the layer actor.
     * @param x The x coördinate of the new location
     * of the actor.
     * @param y The y coördinate of the new location
     * of the actor.
     */
    public void setLocation(int x, int y)
    {
        testLayer();
        int realX = x -layer.getX();
        int realY = y -layer.getY();
        if (layer.isBounded()) {
            if (realX < 0)
                realX = 0;
            else if (realX > layer.getWidth())
                realX = layer.getWidth() -1;
            if (realY < 0)
                realY = 0;
            else if (realY > layer.getHeight())
                realY = layer.getHeight() -1;
        }
        super.setLocation(realX +layer.getX(),
                          realY +layer.getY());
        oldX = getX();
        oldY = getY();
    }
    
    /**
     * Used by the system: don't touch!
     */
    void setLayer(Layer layer)
    {
        this.layer = layer;
    }
    
    private void testLayer()
    {
        if (this.layer == null)
            throw new IllegalStateException("The actor"+
            " isn't inserted in a layer (yet)");
    }
}