import greenfoot.*;
import java.util.ArrayList;

/**
 * A world which is a collection of layers.<p>
 * 
 * The world starts off with one layer: the
 * <b>main layer</b>. This one has the same
 * width and height as the world, and starts off
 * at location {@link (0,0)}. You can access
 * it by the {@link getMainLayer} method, and you're
 * free to add objects to it or change it's location.
 * 
 * @author Sven van Nigtevecht
 * @version 1.0
 */
public class LayerWorld extends World
{
    private final boolean bounded;
    private final ArrayList<Layer> layers;
    private final Layer mainLayer;
    
    /**
     * Create a new LayerWorld.
     * @param width The width of the world.
     * @param height The height of the world.
     */
    public LayerWorld(int width, int height)
    {
        this(width,height,true);
    }
    
    /**
     * Create a new LayerWorld.
     * @param width The width of the world.
     * @param height The height of the world.
     * @param bounded Are the layers limited to the
     * world's boundary?
     */
    public LayerWorld(int width, int height, boolean bounded)
    {
        super(width,height,1,bounded);
        this.bounded = bounded;
        this.layers = new ArrayList<Layer>();
        this.mainLayer = new Layer(width, height, bounded);
        addLayer(mainLayer,0,0);
    }
    
    /**
     * Returns the main layer of the world.
     */
    public Layer getMainLayer()
    {
        return mainLayer;
    }
    
    /**
     * Are the layers limited to the world's boundary?
     */
    public boolean isBounded()
    {
        return bounded;
    }
    
    /**
     * Adds a layer to the world.
     * @param layer The layer which will be added to the
     * world.
     * @param x The x coördinate the layer will be added at.
     * @param y The y coördinate the layer will be added at.
     */
    public void addLayer(Layer layer, int x, int y)
    {
        layers.add(layer);
        layer.setWorld(this);
        layer.setLocation(x,y);
    }
}